==> plugin-android-7.1.3-sources.jar: com/zoyi/channel/plugin/android/global/Const.java <==
package com.zoyi.channel.plugin.android.global;

/**
 * Created by mika on 2016. 12. 6..
 */
public class Const {

  public final static String UPDATED_AT = "updatedAt";
  public final static String DESC = "DESC";
  public final static long TYPING_PRIMARY_KEY = Long.MAX_VALUE - 2;
  public final static long FAILED_FILE_PRIMARY_KEY = Long.MAX_VALUE - 1;
  public final static long SENDING_FILE_PRIMARY_KEY = Long.MAX_VALUE;
  public final static long MESSAGE_PRIMARY_KEY_MAX = Long.MAX_VALUE - 1000;

  public final static String USER_CHAT_HANDLING_SUPPORT = "support";

  public final static String USER_CHAT_STATE_CLOSED = "closed";
  public final static String USER_CHAT_STATE_SOLVED = "solved";
  public final static String USER_CHAT_STATE_REMOVED = "trash";

  public static final String USER_CHAT_LOG_ACTION_CLOSE = "close";

  public static final String AWAY_OPTION_ACTIVE = "active";
  public static final String AWAY_OPTION_HIDDEN = "hidden";

  public static final String WORKING_TYPE_ALWAYS = "always";
  public static final String WORKING_TYPE_NEVER = "never";
  public static final String WORKING_TYPE_CUSTOM = "custom";

  public final static int PHOTO_REQUEST_CODE = 902;
  public final static int PHOTO_SELECT_LIMIT = 20;
  public final static int PHOTO_RESULT_CODE = 12;
  public final static String PHOTO_INTENT_KEY = "PHOTO_INTENT_KEY";

  public final static int MESSAGE_FETCH_LIMIT = 30;

  public final static int DOWNLOAD_COMPLETE = 0;
  public final static int DOWNLOAD_CANCEL = 1;
  public final static int DOWNLOAD_FAILED = 2;
  public final static String EXTERNAL_DOWNLOAD_PATH = "ChannelPlugin";

  public static final int COLUMNS_PHOTO_PICKER = 3;

  public static final int REQUEST_CHAT = 21;
  public static final int REQUEST_TAKE_PHOTO = 3000;
  public static final int REQUEST_PHOTO_ALBUM = 3001;
  public static final int REQUEST_PUSH_MESSAGE = 999998;

  public static final int RESULT_CHAT_OPEN_NEW_CHAT = 22;
  public static final int RESULT_PHOTO_CODE = 12;

  public final static String REQUEST_CODE_INTENT_KEY = "REQUEST_CODE_INTENT_KEY";

  public static final String EXTRA_CHAT_CONTENT_ID = "chatContentId";
  public static final String EXTRA_CHAT_CONTENT_TYPE = "chatContentType";
  public static final String EXTRA_URL = "url";
  public static final String EXTRA_FILE_NAME = "filename";
  public static final String EXTRA_IMAGE = "image";
  public static final String EXTRA_MESSAGE = "message";
  public static final String EXTRA_SOUND = "sound";
  public static final String EXTRA_CHANNEL_ID = "channelId";
  public static final String EXTRA_CHAT_TYPE = "chatType";
  public static final String EXTRA_CHAT_ID = "chatId";
  public static final String EXTRA_PROVIDER = "provider";
  public static final String EXTRA_HOST_APP_INTENT = "host_app_intent";
  public static final String EXTRA_REDIRECT_ANIMATED = "animated";
  public static final String EXTRA_PROFILE_KEY = "EXTRA_PROFILE_KEY";
  public static final String EXTRA_PROFILE_VALUE = "EXTRA_PROFILE_VALUE";
  public static final String EXTRA_TOP_ACTIVITY_NAME = "topActivityName";
  public static final String EXTRA_START_AT = "EXTRA_START_AT";
  public static final String EXTRA_PERSON_TYPE = "personType";
  public static final String EXTRA_PERSON_ID = "personId";
  public static final String EXTRA_AVATAR_URL = "avatarUrl";

  public static final String PROFILE_TYPE_NUMBER = "number";

  public static final String UTM_URL = "https://channel.io/%s/?utm_source=%s&utm_medium=plugin&utm_campaign=android&utm_content=%s&utm_channel_id=%s";
  public static final String UTM_PATH_WATERMARK = "plugin_watermark";

  // Call headers
  public static final String X_SESSION = "x-session";
  public static final String X_CHANNEL_SDK = "x-channel-sdk";
  public static final String X_HOST_APP = "x-host-app";

  public static final String ACCEPT_LANGUAGE = "Accept-Language";

  // Locale
  public static final String ENGLISH = "en";
  public static final String KOREAN = "ko";
  public static final String JAPANESE = "ja";

  // Profile
  public static final String PROFILE_NAME_KEY = "name";
  public static final String PROFILE_AVATAR_URL_KEY = "avatarUrl";
  public static final String PROFILE_MOBILE_NUMBER_KEY = "mobileNumber";
  public static final String PROFILE_EMAIL_KEY = "email";

  // Value
  public static final String PACKAGE_NAME = "com.zoyi.channel.plugin.android";

  public static final String USER = "user";
  public static final String BOT = "bot";
  public static final String MANAGER = "manager";

  public static final String ACTION_TYPE_SOLVE = "userChat.solve";
  public static final String ACTION_TYPE_CLOSE = "userChat.close";
  public static final String ACTION_TYPE_SUPPORT_BOT = "supportBot";

  public static final String ACTION_KEY_REOPEN = "reopen";
  public static final String ACTION_KEY_CLOSE = "close";
  public static final String ACTION_KEY_LIKE = "like";
  public static final String ACTION_KEY_DISLIKE = "dislike";

  public static final String REVIEW_LIKE = "like";
  public static final String REVIEW_DISLIKE = "dislike";

  public static final String ERROR_UNKNOWN = "Unknown error";

  public static final String PROPERTY_URL = "url";

  public static final String SYS_PROPERTY_PLUGIN_VERSION = "pluginVersion";
  public static final String SYS_PROPERTY_SCREEN_WIDTH = "screenWidth";
  public static final String SYS_PROPERTY_SCREEN_HEIGHT = "screenHeight";
  public static final String SYS_PROPERTY_URL = "url";

  public static final String DEFAULT_ANDROID_USER_AGENT = "http.agent";
  public static final String HEADER_USER_AGENT = "User-Agent";
  public static final String FORMAT_USER_AGENT_MOBILE = "%s %s Mobile ChannelSDK/%s";
  public static final String FORMAT_USER_AGENT_NOT_MOBILE = "%s %s ChannelSDK/%s";
  public static final String FORMAT_USER_AGENT_MOBILE_APP_INFO = "%s/%s";

  public static final String FORMAT_PUSH_TOKENS_KEY = "android-%s";

  public static final String CHAT_CONTENT_USER_CHAT = "USER_CHAT";
  public static final String CHAT_CONTENT_SUPPORT_BOT = "SUPPORT_BOT";
  public static final String CHAT_CONTENT_NONE = "NONE";

  public static final String TYPING_START = "start";
  public static final String TYPING_STOP = "stop";

  public static final String PAGE_VIEW_EVENT_NAME = "PageView";

  public static final boolean DEFAULT_SETTINGS_HIDE_DEFAULT_IN_APP_PUSH = false;
  public static final boolean DEFAULT_SETTINGS_ENABLED_TRACK_DEFAULT_EVENT = true;

  public static final int LOUNGE_PREVIEW_MAX_CHATS = 3;

  public static final String FORMAT_THUMB_URL = "%s/thumb/%dx%d,cover/%s";

  public static final String FIELD_SOCKET_ID = "id";
  public static final String FIELD_SOCKET_TYPE = "type";
  public static final String FIELD_SOCKET_ENTITY = "entity";
  public static final String FIELD_SOCKET_REFERS = "refers";
  public static final String FIELD_SOCKET_BOT = "bot";
  public static final String FIELD_SOCKET_MANAGER = "manager";
  public static final String FIELD_SOCKET_MESSAGE = "message";
  public static final String FIELD_SOCKET_USER_CHAT = "userChat";
  public static final String FIELD_SOCKET_USER = "user";

  public static final String FIELD_PLAIN_TEXT = "plainText";
  public static final String FIELD_REQUEST_ID = "requestId";
  public static final String FIELD_SUBMIT = "submit";
  public static final String FIELD_ID = "id";
  public static final String FIELD_KEY = "key";

  public static final String FILE_TYPE_IMAGE = "image";
  public static final String FILE_TYPE_VIDEO = "video";

  public static final String FORMAT_DURATION_HOUR = "%d:%d:%d";
  public static final String FORMAT_DURATION_MINUTE = "%d:%d";

  public static final long SENDING_MESSAGE_PRIMARY_KEY_MULTIPLER = 10L;
  public static final String DEFAULT_FILE_NAME = "file";

  public static final String PUBLISHER_YOUTUBE = "YouTube";

  public static final String FILE_ICON_PATH = "asset/file-icon/images/%s@2x.png";

  // Block type
  public static final String BLOCK_TYPE_TEXT = "text";
  public static final String BLOCK_TYPE_BULLETS = "bullets";
  public static final String BLOCK_TYPE_CODE = "code";

  // attribute key name
  public static final String TAG_ATTR_KEY_TYPE = "type";
  public static final String TAG_ATTR_KEY_VALUE = "value";

  // TYPE : TAG
  public static final String TAG_TYPE_BOLD = "b";
  public static final String TAG_TYPE_ITALIC = "i";
  public static final String TAG_TYPE_LINK = "link";

  // TYPE : link
  public static final String LINK_TYPE_URL = "url";
  public static final String LINK_TYPE_EMAIL = "email";
  public static final String LINK_TYPE_MENTION = "manager";

  // TYPE : Marketing exposure
  public static final String EXPOSURE_TYPE_FULL_SCREEN = "fullScreen";

  public static final int USER_CHATS_LIMIT = 50;
  public static final int COUNT_LIMIT = 99;

  public static final String MESSAGE_STATE_REMOVED = "removed";

  // TYPE : Marketing
  public static final String MARKETING_TYPE_CAMPAIGN = "campaign";
  public static final String MARKETING_TYPE_ONE_TIME_MSG = "oneTimeMsg";

  public static final String PAYMENT_STATE_UNPAID = "unpaid";

  // WorkingTime
  public static final String DAY_OF_WEEK_MON = "mon";
  public static final String DAY_OF_WEEK_TUE = "tue";
  public static final String DAY_OF_WEEK_WED = "wed";
  public static final String DAY_OF_WEEK_THU = "thu";
  public static final String DAY_OF_WEEK_FRI = "fri";
  public static final String DAY_OF_WEEK_SAT = "sat";
  public static final String DAY_OF_WEEK_SUN = "sun";

  public static final String EXCEPTION_UNKNOWN = "Unknown Error";

  // updateUser
  public static final String USER_DATA_LANGUAGE = "language";
  public static final String USER_DATA_TAGS = "tags";
  public static final String USER_DATA_PROFILE = "profile";
  public static final String USER_DATA_PROFILE_ONCE = "profileOnce";
  public static final String USER_DATA_UNSUBSCRIBED = "unsubscribed";
}

==> plugin-android-8.0.0-sources.jar: com/zoyi/channel/plugin/android/global/Const.java <==
package com.zoyi.channel.plugin.android.global;

/**
 * Created by mika on 2016. 12. 6..
 */
public class Const {

  public final static String UPDATED_AT = "updatedAt";
  public final static String DESC = "DESC";
  public final static long TYPING_PRIMARY_KEY = Long.MAX_VALUE - 2;
  public final static long FAILED_FILE_PRIMARY_KEY = Long.MAX_VALUE - 1;
  public final static long SENDING_FILE_PRIMARY_KEY = Long.MAX_VALUE;
  public final static long MESSAGE_PRIMARY_KEY_MAX = Long.MAX_VALUE - 1000;

  public final static String USER_CHAT_HANDLING_SUPPORT = "support";

  public final static String USER_CHAT_STATE_CLOSED = "closed";
  public final static String USER_CHAT_STATE_SOLVED = "solved";
  public final static String USER_CHAT_STATE_REMOVED = "trash";

  public static final String USER_CHAT_LOG_ACTION_CLOSE = "close";

  public static final String AWAY_OPTION_ACTIVE = "active";
  public static final String AWAY_OPTION_DISABLED = "disabled";
  public static final String AWAY_OPTION_HIDDEN = "hidden";

  public static final String WORKING_TYPE_ALWAYS = "always";
  public static final String WORKING_TYPE_NEVER = "never";
  public static final String WORKING_TYPE_CUSTOM = "custom";

  public final static int PHOTO_REQUEST_CODE = 902;
  public final static int PHOTO_SELECT_LIMIT = 20;
  public final static int PHOTO_RESULT_CODE = 12;
  public final static String PHOTO_INTENT_KEY = "PHOTO_INTENT_KEY";

  public final static int MESSAGE_FETCH_LIMIT = 30;

  public final static int DOWNLOAD_COMPLETE = 0;
  public final static int DOWNLOAD_CANCEL = 1;
  public final static int DOWNLOAD_FAILED = 2;
  public final static String EXTERNAL_DOWNLOAD_PATH = "ChannelPlugin";

  public static final int COLUMNS_PHOTO_PICKER = 3;

  public static final int REQUEST_CHAT = 21;
  public static final int REQUEST_TAKE_PHOTO = 3000;
  public static final int REQUEST_PHOTO_ALBUM = 3001;
  public static final int REQUEST_PUSH_MESSAGE = 999998;

  public static final int RESULT_CHAT_OPEN_NEW_CHAT = 22;
  public static final int RESULT_PHOTO_CODE = 12;

  public final static String REQUEST_CODE_INTENT_KEY = "REQUEST_CODE_INTENT_KEY";

  public static final String EXTRA_CHAT_CONTENT_ID = "chatContentId";
  public static final String EXTRA_CHAT_CONTENT_TYPE = "chatContentType";
  public static final String EXTRA_CHAT_PRESET_MESSAGE = "chatPresetMessage";
  public static final String EXTRA_HANDLE_OPEN_CHAT = "handleOpenChat";
  public static final String EXTRA_URL = "url";
  public static final String EXTRA_FILE_NAME = "filename";
  public static final String EXTRA_ATTACHMENT_ID = "attachementId";
  public static final String EXTRA_STORAGE_ID = "storageId";
  public static final String EXTRA_IMAGE = "image";
  public static final String EXTRA_MESSAGE = "message";
  public static final String EXTRA_SOUND = "sound";
  public static final String EXTRA_CHANNEL_ID = "channelId";
  public static final String EXTRA_CHAT_TYPE = "chatType";
  public static final String EXTRA_CHAT_ID = "chatId";
  public static final String EXTRA_PROVIDER = "provider";
  public static final String EXTRA_HOST_APP_INTENT = "host_app_intent";
  public static final String EXTRA_REDIRECT_ANIMATED = "animated";
  public static final String EXTRA_PROFILE_KEY = "EXTRA_PROFILE_KEY";
  public static final String EXTRA_PROFILE_VALUE = "EXTRA_PROFILE_VALUE";
  public static final String EXTRA_TOP_ACTIVITY_NAME = "topActivityName";
  public static final String EXTRA_START_AT = "EXTRA_START_AT";
  public static final String EXTRA_PERSON_TYPE = "personType";
  public static final String EXTRA_PERSON_ID = "personId";
  public static final String EXTRA_AVATAR_URL = "avatarUrl";

  public static final String PROFILE_TYPE_NUMBER = "number";
  public static final String PROFILE_TYPE_DATE = "date";
  public static final String PROFILE_TYPE_BOOLEAN = "boolean";

  public static final String UTM_URL = "https://channel.io/%s/?utm_source=%s&utm_medium=plugin&utm_campaign=android&utm_content=%s&utm_channel_id=%s";
  public static final String UTM_PATH_WATERMARK = "plugin_watermark";

  // Call headers
  public static final String X_SESSION = "x-session";
  public static final String X_CHANNEL_SDK = "x-channel-sdk";
  public static final String X_HOST_APP = "x-host-app";

  public static final String ACCEPT_LANGUAGE = "Accept-Language";

  // Locale
  public static final String ENGLISH = "en";
  public static final String KOREAN = "ko";
  public static final String JAPANESE = "ja";

  // Profile
  public static final String PROFILE_NAME_KEY = "name";
  public static final String PROFILE_AVATAR_URL_KEY = "avatarUrl";
  public static final String PROFILE_MOBILE_NUMBER_KEY = "mobileNumber";
  public static final String PROFILE_EMAIL_KEY = "email";

  // Value
  public static final String PACKAGE_NAME = "com.zoyi.channel.plugin.android";

  public static final String USER = "user";
  public static final String BOT = "bot";
  public static final String MANAGER = "manager";

  public static final String ACTION_TYPE_SOLVE = "userChat.solve";
  public static final String ACTION_TYPE_CLOSE = "userChat.close";
  public static final String ACTION_TYPE_SUPPORT_BOT = "supportBot";

  public static final String ACTION_KEY_REOPEN = "reopen";
  public static final String ACTION_KEY_CLOSE = "close";
  public static final String ACTION_KEY_LIKE = "like";
  public static final String ACTION_KEY_DISLIKE = "dislike";

  public static final String REVIEW_LIKE = "like";
  public static final String REVIEW_DISLIKE = "dislike";

  public static final String ERROR_UNKNOWN = "Unknown error";

  public static final String PROPERTY_URL = "url";

  public static final String SYS_PROPERTY_PLUGIN_VERSION = "pluginVersion";
  public static final String SYS_PROPERTY_SCREEN_WIDTH = "screenWidth";
  public static final String SYS_PROPERTY_SCREEN_HEIGHT = "screenHeight";
  public static final String SYS_PROPERTY_URL = "url";

  public static final String DEFAULT_ANDROID_USER_AGENT = "http.agent";
  public static final String HEADER_USER_AGENT = "User-Agent";
  public static final String FORMAT_USER_AGENT_MOBILE = "%s %s Mobile ChannelSDK/%s";
  public static final String FORMAT_USER_AGENT_NOT_MOBILE = "%s %s ChannelSDK/%s";
  public static final String FORMAT_USER_AGENT_MOBILE_APP_INFO = "%s/%s";

  public static final String FORMAT_PUSH_TOKENS_KEY = "android-%s";

  public static final String CHAT_CONTENT_USER_CHAT = "USER_CHAT";
  public static final String CHAT_CONTENT_SUPPORT_BOT = "SUPPORT_BOT";
  public static final String CHAT_CONTENT_NONE = "NONE";

  public static final String TYPING_START = "start";
  public static final String TYPING_STOP = "stop";

  public static final String PAGE_VIEW_EVENT_NAME = "PageView";

  public static final boolean DEFAULT_SETTINGS_HIDE_DEFAULT_IN_APP_PUSH = false;
  public static final boolean DEFAULT_SETTINGS_ENABLED_TRACK_DEFAULT_EVENT = true;

  public static final int LOUNGE_PREVIEW_MAX_CHATS = 3;

  public static final String FORMAT_THUMB_URL = "%s/thumb/%dx%d,cover/%s";

  public static final String FIELD_SOCKET_ID = "id";
  public static final String FIELD_SOCKET_TYPE = "type";
  public static final String FIELD_SOCKET_ENTITY = "entity";
  public static final String FIELD_SOCKET_REFERS = "refers";
  public static final String FIELD_SOCKET_BOT = "bot";
  public static final String FIELD_SOCKET_MANAGER = "manager";
  public static final String FIELD_SOCKET_MESSAGE = "message";
  public static final String FIELD_SOCKET_USER_CHAT = "userChat";
  public static final String FIELD_SOCKET_USER = "user";

  public static final String FIELD_PLAIN_TEXT = "plainText";
  public static final String FIELD_REQUEST_ID = "requestId";
  public static final String FIELD_SUBMIT = "submit";
  public static final String FIELD_ID = "id";
  public static final String FIELD_KEY = "key";

  public static final String FILE_TYPE_IMAGE = "image";
  public static final String FILE_TYPE_VIDEO = "video";

  public static final String FORMAT_DURATION_HOUR = "%d:%d:%d";
  public static final String FORMAT_DURATION_MINUTE = "%d:%d";

  public static final long SENDING_MESSAGE_PRIMARY_KEY_MULTIPLER = 10L;
  public static final String DEFAULT_FILE_NAME = "file";

  public static final String PUBLISHER_YOUTUBE = "YouTube";

  public static final String FILE_ICON_PATH = "asset/file-icon/images/%s@2x.png";

  // Block type
  public static final String BLOCK_TYPE_TEXT = "text";
  public static final String BLOCK_TYPE_BULLETS = "bullets";
  public static final String BLOCK_TYPE_CODE = "code";

  // attribute key name
  public static final String TAG_ATTR_KEY_TYPE = "type";
  public static final String TAG_ATTR_KEY_VALUE = "value";

  // TYPE : BootStatus
  public static final String BOOT_STATUS_SUCCESS = "SUCCESS";
  public static final String BOOT_STATUS_NOT_INITIALIZED = "NOT_INITIALIZED";
  public static final String BOOT_STATUS_NETWORK_TIMEOUT = "NETWORK_TIMEOUT";
  public static final String BOOT_STATUS_NOT_AVAILABLE_VERSION = "NOT_AVAILABLE_VERSION";
  public static final String BOOT_STATUS_SERVICE_UNDER_CONSTRUCTION = "SERVICE_UNDER_CONSTRUCTION";
  public static final String BOOT_STATUS_REQUIRE_PAYMENT = "REQUIRE_PAYMENT";
  public static final String BOOT_STATUS_ACCESS_DENIED = "ACCESS_DENIED";
  public static final String BOOT_STATUS_UNKNOWN_ERROR = "UNKNOWN_ERROR";

  // TYPE : TAG
  public static final String TAG_TYPE_BOLD = "b";
  public static final String TAG_TYPE_ITALIC = "i";
  public static final String TAG_TYPE_LINK = "link";

  // TYPE : link
  public static final String LINK_TYPE_URL = "url";
  public static final String LINK_TYPE_EMAIL = "email";
  public static final String LINK_TYPE_MENTION = "manager";

  // TYPE : Marketing exposure
  public static final String EXPOSURE_TYPE_FULL_SCREEN = "fullScreen";

  public static final int USER_CHATS_LIMIT = 50;
  public static final int COUNT_LIMIT = 99;

  public static final String MESSAGE_STATE_REMOVED = "removed";

  // TYPE : Marketing
  public static final String MARKETING_TYPE_CAMPAIGN = "campaign";
  public static final String MARKETING_TYPE_ONE_TIME_MSG = "oneTimeMsg";

  // WorkingTime
  public static final String DAY_OF_WEEK_MON = "mon";
  public static final String DAY_OF_WEEK_TUE = "tue";
  public static final String DAY_OF_WEEK_WED = "wed";
  public static final String DAY_OF_WEEK_THU = "thu";
  public static final String DAY_OF_WEEK_FRI = "fri";
  public static final String DAY_OF_WEEK_SAT = "sat";
  public static final String DAY_OF_WEEK_SUN = "sun";

  public static final String EXCEPTION_UNKNOWN = "Unknown Error";

  // updateUser
  public static final String USER_DATA_LANGUAGE = "language";
  public static final String USER_DATA_TAGS = "tags";
  public static final String USER_DATA_PROFILE = "profile";
  public static final String USER_DATA_PROFILE_ONCE = "profileOnce";
  public static final String USER_DATA_UNSUBSCRIBED = "unsubscribed";

  // ButtonTheme
  public static final String MESSAGE_LINK_BUTTON_BLUE = "blue";
  public static final String MESSAGE_LINK_BUTTON_GREEN = "green";
  public static final String MESSAGE_LINK_BUTTON_ORANGE = "orange";
  public static final String MESSAGE_LINK_BUTTON_RED = "red";
}
